@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
+ * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2013 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    HashTable
  * @subpackage UnitTests
@@ -17,17 +17,15 @@
  *
  * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2013 Horde LLC
- * @ignore
+ * @copyright  2013-2015 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    HashTable
  * @subpackage UnitTests
  */
 class Horde_HashTable_Driver_MemoryTest extends Horde_HashTable_Driver_TestBase
 {
-    static public function setUpBeforeClass()
+    public static function setUpBeforeClass()
     {
         self::$_driver = new Horde_HashTable_Memory();
     }
-
 }
