@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -25,7 +25,16 @@
  */
 abstract class Horde_HashTable_Driver_TestBase extends Horde_Test_Case
 {
-    static protected $_driver;
+    protected static $_driver;
+
+    protected static $_skip = false;
+
+    public function setUp()
+    {
+        if (self::$_skip) {
+            $this->markTestSkipped(self::$_skip);
+        }
+    }
 
     public function testSet()
     {
